var Button = function(x, y, text, key, callback, callbackContext, scale, expandTo, shrinkTo, wait, overFrame, outFrame, downFrame, upFrame) {
	// Call constructor of phaser button object
	Phaser.Button.call(this, game, x, y, key, callback,
		callbackContext, overFrame, outFrame, downFrame, upFrame);
	
	game.add.existing(this);

	this.scaleVal = scale || 1;
	this.expandTo = expandTo || this.scaleVal * 1.25;
	this.shrinkTo = shrinkTo || this.scaleVal;
	this.anchor.set(0.5);
	this.scale.set(this.scaleVal);
	this.input.useHandCursor = true;
	this.wait = wait || false;
	this.active = true;

	this.justClicked = false;

	// if you need to wait for buttons to pop in from another event
	// you won't want the onOver and Out events of the button to interfere
	// set active to true once event is over
	if(this.wait) {
		this.active = false;
	}

	// Add text to button
	this.text = new Text(game, 0, 0, text.toUpperCase(), 'small', 'center', false);
	this.text.anchor.set(0.5, 0.43);
	this.addChild(this.text);

	// Events
	this.events.onInputOver.add(this.onOver, this);
	this.events.onInputOut.add(this.onOut, this);
	this.events.onInputDown.add(this.onClick, this);
};

Button.prototype = Object.create(Phaser.Button.prototype);
Button.prototype.constructor = Button;

Button.prototype.onOver = function(button) {
	if(this.active) {
		var t = game.add.tween(button.scale);
		t.to({x: this.expandTo, y: this.expandTo }, 150, Phaser.Easing.Quadratic.Out).to({x: this.expandTo - 0.05, y: this.expandTo - 0.05 }, 150, Phaser.Easing.Quadratic.In);
		t.start();
		if (this.soundOver && !this.justClicked)
			this.soundOver.play();
		this.justClicked = false;
	}
};

Button.prototype.onOut = function(button) {
	if(this.active) {
		var t = game.add.tween(button.scale);
		t.to({x: this.shrinkTo, y: this.shrinkTo }, 150, Phaser.Easing.Quadratic.Out).to({x: this.shrinkTo + 0.05, y: this.shrinkTo + 0.05 }, 150, Phaser.Easing.Quadratic.In);
		t.start();
	}
};

Button.prototype.onClick = function(button){
	if (this.active){
		this.justClicked = true;
	}
};

Button.prototype.popIn = function(delay) {
	var delay = delay || 0;
	Utils.Tween.In(game, this.scale, {x: this.expandTo, y: this.expandTo }, {x: this.shrinkTo, y: this.shrinkTo }, delay);
};

Button.prototype.popOut = function (callback, callbackContext) {
	Utils.Tween.Out(game, this.scale, {x: this.expandTo, y: this.expandTo}, {x: 0, y: 0}, 0, callback, callbackContext);
}