GameStates.SelectGlitter = function () {
    this.canisterStroke;
    this.timeGap = 70;
    this.characterGroup;
    this.glowGroup;
    this.glowingParts;
    this.pointer;
    this.pointerTween;
    this.text;
    this.firstClick;
    this.firstPartClick;
    this.canisters;
    this.canisterMasks;
    this.back;
    this.front;
    this.emitter;
};

GameStates.SelectGlitter.prototype = {
    create: function () {
        // reset selectedParts array
        selectedParts = [];
        this.glowingParts = [];
        this.canisters = [];
        this.canisterMasks = [];
        this.firstClick = true;
        this.firstPartClick = true;
		
        // background
        game.add.sprite(0, 0, 'backstage');
        var stage = game.add.sprite(0, 0, 'stage');

        this.back = game.add.group();
        this.characterGroup = game.add.group();
        this.glowGroup = game.add.group();
        this.front = game.add.group();

        // tween blurry stage out
        Utils.Tween.Out(game, stage, { alpha: 1 }, { alpha: 0 });
		
        // create character
        this.createCharacter();

        // create canister
        this.createCanisters();

        // add button to go to glitterize
        this.button = new Button(game.width * 0.7, game.height * 0.9, copy.glitterizeButton, 'button-blue', this.glitterize, this);
        this.button.scale.set(0);
		
        // pointer animate for canisters
        this.pointer = game.add.sprite(game.width * 0.45, game.height * 0.65, 'pointer');
        this.pointer.scale.set(0.5);
        this.pointer.anchor.set(0.5);

        var tweenX = this.pointer.x - 20;
        var tweenY = this.pointer.y + 20;

        // tween loop the pointer
        this.pointerTween = game.add.tween(this.pointer).to({ x: tweenX, y: tweenY }, 700, Phaser.Easing.Quadratic.InOut, true, 0, -1, true);

        // text
        this.text = new Text(game, game.width / 2, 50, copy.selectCanister.toUpperCase(), 'medium', 'center', '#5f259f');
        this.text.anchor.set(0.5);
    },

    advanceInstructions: function () {
        if (this.firstClick) {
            // when clicked for the first time
            // tween loop the pointer
            Utils.Tween.In(game, this.pointer, { alpha: 0 }, { alpha: 0 }, 0, function () {
                this.pointer.scale.set(-0.5, 0.5);

                this.pointer.x = game.width * 0.55;
                this.pointer.y = game.height * 0.2;
                var tweenX = this.pointer.x + 20;
                var tweenY = this.pointer.y + 20;
                this.pointerTween = game.add.tween(this.pointer).to({ x: tweenX, y: tweenY }, 700, Phaser.Easing.Quadratic.InOut, true, 0, -1, true);

                Utils.Tween.In(game, this.pointer, { alpha: 1 }, { alpha: 1 });
            }, this);

            // text
            this.text.destroy();
            this.text = new Text(game, game.width / 2, 60, copy.selectPart.toUpperCase(), 'medium', 'center', '#5f259f');
            this.text.anchor.set(0.5);
            this.firstClick = false;

            this.glowingParts.forEach(function (tween) {
                tween.resume();
            });

            // show the character
            this.characterGroup.y += 50;

            Utils.Tween.In(game, this.characterGroup, { alpha: 1 }, { alpha: 1 }, 0);
            Utils.Tween.In(game, this.characterGroup, { y: -10 }, { y: 0 }, 0);

            this.glowGroup.y += 50;

            Utils.Tween.In(game, this.glowGroup, { alpha: 1 }, { alpha: 1 }, 0);
            Utils.Tween.In(game, this.glowGroup, { y: -10 }, { y: 0 }, 0);
        }
    },

    showButton: function () {
        if (this.firstPartClick) {
            // bring glitterizer button in and hide pointer
            this.pointerTween.stop();
            this.pointer.destroy();

            // text
            this.text.destroy();
            this.text = new Text(game, game.width / 2, 60, copy.glitterize.toUpperCase(), 'medium', 'center', '#5f259f');
            this.text.anchor.set(0.5);

            Utils.Tween.In(game, this.button.scale, { x: 1.1, y: 1.1 }, { x: 1, y: 1 });

            this.firstPartClick = false;
        }
    },

    createCanisters: function() {
        // create canisters
        for (var i = 0, ilen = data.glitters.length; i < ilen; i++) {
            // set stroke around first canister
            if (i == 0) {
                this.canisterStroke = game.add.sprite(i * 80 + 105, 395, 'canister-stroke');
                this.canisterStroke.scale.set(0.5);
                selectedCanister = i;

                this.canisterStroke.alpha = 0;
                this.canisterStroke.angle += 90;
            }

            // add respective glitter with mask
            var bmd = game.make.bitmapData(320, 206);

            //	And create an alpha mask image by combining pic and mask from the cache
            bmd.alphaMask(data.glitters[i].key, 'canister-mask');

            //	A BitmapData is just a texture. You need to apply it to a sprite or image
            //	to actually display it:
            var mask = game.add.sprite(i * 80 + 100, 400, bmd);
            mask.scale.set(0.5);
            mask.angle += 90;
            this.canisterMasks.push(mask);

            // add canister over top the glitter
            var canister = game.add.sprite(i * 80 + 100, 400, 'canister');
            canister.scale.set(0.5);
            canister.angle += 90;
            canister.inputEnabled = true;
            canister.input.useHandCursor = true;
            this.canisters.push(canister);
            this.selectCanister(canister, i, this.canisterStroke);

            // tween in canister mask
            mask.alpha = 0;
            mask.y += 50;

            Utils.Tween.In(game, mask, { alpha: 1 }, { alpha: 1 }, ilen * this.timeGap - i * this.timeGap);
            Utils.Tween.In(game, mask, { y: 390 }, { y: 400 }, ilen * this.timeGap - i * this.timeGap);

            // tween in canister
            canister.alpha = 0;
            canister.y += 50;

            Utils.Tween.In(game, canister, { alpha: 1 }, { alpha: 1 }, ilen * this.timeGap - i * this.timeGap);
            Utils.Tween.In(game, canister, { y: 390 }, { y: 400 }, ilen * this.timeGap - i * this.timeGap);
        }
    },
	
	selectCanister: function (canister, index, canisterStroke) {
		canister.events.onInputDown.add(function () {
		    selectedCanister = index;
		    canisterStroke.x = index * 80 + 105;
		    canisterStroke.alpha = 1;

		    this.advanceInstructions();
		}, this);
	},

	createCharacter: function () {
	    // create selected character and pose
	    var shadow = game.add.sprite(game.width * 0.7, game.height * 0.51, data.characters[selectedCharacter].name + '-' + selectedPose + '-shadow');
	    // SHADOWS TURNED OFF
	    shadow.visible = false;
	    shadow.anchor.set(0.5);
	    shadow.scale.set(0.8);
        this.characterGroup.add(shadow);

	    var part;
	    for (var i = 0, ilen = data.characters[selectedCharacter].poses[selectedPose].parts.length; i < ilen; i++) {
	        var glowPart;

	        // create part
	        part = new Part(game.width * 0.7, game.height * 0.51, data.characters[selectedCharacter].poses[selectedPose].parts[i].key, 0.8);
	        this.select(part, i, false);
	        this.characterGroup.add(part);

	        // if selectable create a glow part and make it clickable
	        if (data.characters[selectedCharacter].poses[selectedPose].parts[i].selectable) {
	            var glowPart = new Part(game.width * 0.7, game.height * 0.51, data.characters[selectedCharacter].poses[selectedPose].parts[i].key + '-glow', 0.8); // change key to glow
	            this.select(glowPart, i, true);
	            this.glowGroup.add(glowPart);
	            glowPart.alpha = 0.2;

	            this.glowingParts[i] = game.add.tween(glowPart).to({ alpha: 0.8 }, 700, Phaser.Easing.Quadratic.InOut, true, i * 200, -1, true);
	            this.glowingParts[i].pause();
	        }
	    }

	    this.characterGroup.alpha = 0;
	    this.glowGroup.alpha = 0;
	},
	
	select: function (part, index, selectable) {
	    // only click selectable parts
		if(selectable) {
			part.events.onInputDown.add(function () {
				if(!part.selected) {
					// show indication part is selected
				    part.tint = "0xedd0ef0";
				    this.glowingParts[index].pause();
				    part.alpha = 1;

				    // add to selected
					part.selected = true;
					selectedParts.push(index);
				}
				else {
					// remove indication part is selected
				    part.tint = "0xffffff";
				    this.glowingParts[index].resume();

					// remove from selected
					part.selected = false;
					for(var i = 0, len = selectedParts.length; i < len; i++) {
						if(selectedParts[i] == index) {
							selectedParts.splice(i, 1);
							break;
						}
					}
				}

				this.showButton();
			}, this);
		}
	},
	
	glitterize: function () {
	    // hide button
	    this.button.active = false;
	    Utils.Tween.Out(game, this.button.scale, { x: 1.1, y: 1.1 }, { x: 0, y: 0 });

	    // hide text
	    this.text.destroy();

	    // stop pulsing on character
	    this.glowingParts.forEach(function (tween) {
	        tween.stop();
	    });

	    this.glowGroup.destroy();

	    this.hideCanisters();
	    // shut door
	    // wipe glitterizer

	},

	hideCanisters: function () {
	    // hide stroke
	    this.canisterStroke.alpha = 0;

	    // animate canisters off
	    for (var i = 0, len = this.canisters.length; i < len; i++) {
	        Utils.Tween.Out(game, this.canisters[i], { alpha: 1 }, { alpha: 0 }, len * this.timeGap - i * this.timeGap);
	        Utils.Tween.Out(game, this.canisters[i], { y: 390 }, { y: 450 }, len * this.timeGap - i * this.timeGap);
	    }

	    for (var i = 0, len = this.canisterMasks.length; i < len; i++) {
	        Utils.Tween.Out(game, this.canisterMasks[i], { alpha: 1 }, { alpha: 0 }, len * this.timeGap - i * this.timeGap);

	        if (i == 0) {
	            Utils.Tween.Out(game, this.canisterMasks[i], { y: 390 }, { y: 450 }, len * this.timeGap - i * this.timeGap, function () {
                    // call next step
	                this.slideGlitterizer();
	            }, this);
	        }
	        else {
	            Utils.Tween.Out(game, this.canisterMasks[i], { y: 390 }, { y: 450 }, len * this.timeGap - i * this.timeGap);
	        }
	    }
	},

	slideGlitterizer: function () {
	    // mask for door
	    //	A mask is a Graphics object
	    var mask = game.add.graphics(0, 0);

	    //	Shapes drawn to the Graphics object must be filled.
	    mask.beginFill(0xffffff);

	    //	Here we'll draw a rectangle
	    mask.drawRect(420, 100, 170, 300);


	    // slide in glitterizer
	    var glitterizerBack = game.add.sprite(game.width * 0.68, game.height * 0.47, 'glitterizer-back');
	    glitterizerBack.anchor.set(0.5);
	    glitterizerBack.scale.set(1.3);
	    glitterizerBack.alpha = 0;

	    var glitterizerDoor = game.add.sprite(game.width * 0.5, game.height * 0.47, 'glitterizer-door');
	    glitterizerDoor.anchor.set(0.5);
	    glitterizerDoor.scale.set(1.3);
	    glitterizerDoor.alpha = 0;

	    //	And apply it to the Sprite
	    glitterizerDoor.mask = mask;
	    this.characterGroup.mask = mask;

	    var glitterizerFront = game.add.sprite(game.width * 0.68, game.height * 0.47, 'glitterizer-front');
	    glitterizerFront.anchor.set(0.5);
	    glitterizerFront.scale.set(1.3);
	    glitterizerFront.alpha = 0;

	    this.back.add(glitterizerBack);
	    this.front.add(glitterizerDoor);
	    this.front.add(glitterizerFront);

	    Utils.Tween.In(game, glitterizerBack, { alpha: 1 }, { alpha: 1 });
	    Utils.Tween.In(game, glitterizerDoor, { alpha: 1 }, { alpha: 1 });
	    Utils.Tween.In(game, glitterizerFront, { alpha: 1 }, { alpha: 1 }, 0, function () {
	        var extendedX = glitterizerDoor.x + 145;
	        var restingX = glitterizerDoor.x + 135;
	        Utils.Tween.In(game, glitterizerDoor, { x: extendedX }, { x: restingX });
	        this.sparkleTime();
	    }, this);

	},

	update: function () {
	    // fade out the particles
	    if (this.emitter) {
	        this.emitter.forEachAlive(function (particle) {
	            particle.alpha = game.math.clamp(particle.lifespan / 150, 0, 1);
	        }, this);
	    }
	},

	sparkleTime: function () {
	    // make emitter


	    var glitter = game.add.sprite(game.width / 2, game.height / 2, data.glitters[selectedCanister].key);
	    glitter.anchor.set(0.5);
	    glitter.alpha = 0;

	    game.add.tween(glitter).to({ alpha: 1 }, 1000, Phaser.Easing.Linear.None, true);
	    game.add.tween(glitter).to({ angle: 360 }, 3000, Phaser.Easing.Linear.None, true);


	    var particles = [];
	    this.emitter = game.add.emitter(0, 0, 70);

	    // make an array of all the particles' keys
	    data.particles.forEach(function (particle) {
	        particles.push(particle.key);
	    });

	    this.emitter.makeParticles(particles);

	    this.emitter.gravity = -2;
	    this.emitter.maxParticleSpeed = new Phaser.Point(20, 20);
	    this.emitter.minParticleSpeed = new Phaser.Point(-20, -20);
	    this.emitter.width = game.width;
	    this.emitter.height = game.height;
	    this.emitter.start(false, 1000, 200);



	    var overlay = game.add.sprite(0, 0, 'stage');
	    overlay.alpha = 0;
	    Utils.Tween.Out(game, overlay, { alpha: 1 }, { alpha: 1 }, 2600, function () {
            this.state.start('Glitterizer');
	    }, this);
	}
};