/**
	Extended Phaser Text object
	@constructor
	@param {Phaser.Game} game Game object for reference
	@param {int} x X position of text
	@param {int} y Y position of text
	@param {string} text Text to display
	@param {string} size Textual representation of size. Allowed values: xsmall, small, medium, large, xlarge
	@param {string} align Alignment of text. Allowed values: left, center, right. Optional: Defaults to left
	@param {bool} [includeStroke=true] Indicates if stroke should be drawn
	@param {bool} [includeShadow=true] Indicated if drop shadow should be drawn
*/
var Text = function(game, x, y, text, size, align, strokeColor, includeShadow, lineSpacing) {
	// Defaults for falsy values
	if(includeShadow) {
		includeShadow = true;
	}
	
	// normalize strokeColor
	strokeColor = strokeColor ? strokeColor : null;

	// Get pixel size
	var utilSize = this.FontSizes[size];
	var strokeSize = strokeColor ?  (parseInt(utilSize * .08)) + 4 : 0;

	//firefox fix
	if (strokeSize > 0 && firefox)
		strokeSize = 4;

	// Set up style
	var style = {
		font: utilSize + 'px HelveticaRounded',
		fill: '#fff',
		align: align || 'left',
		stroke: strokeColor,
		strokeThickness: strokeSize
	};

	// Call constructor of phaser text object
	Phaser.Text.call(this, game, x, y, text, style);
	this.game.add.existing(this);
	
	this.wordWrap = true;
	this.wordWrapWidth = this.game.world.width;
	this.lineSpacing = lineSpacing || -10;

	if(includeShadow) {
		this.setShadow(2, 2, 'rgba(0, 0, 0, .3)');
	}
};

Text.prototype = Object.create(Phaser.Text.prototype);
Text.prototype.constructor = Text;

Text.prototype.FontSizes = {
	xsmall: '16',
	small: '20',
	medium: '30',
	large: '40',
	xlarge: '70'
};
Text.prototype.PaddingAmounts = {
	xsmall: 10,
	small: 15,
	medium: 20,
	large: 25,
	xlarge: 30
};

var firefox = navigator.userAgent.toLowerCase().indexOf('firefox') > -1;