var Utils = Utils || {};

/**
	A predefined list of tweens
	@class Utils.Tween
*/
Utils.Tween = {
	/**
		Tween in objects using set tween functions
		@method Utils.Tween.In
		@param {object} game game object for context
		@param {object} object object or object property to tween
		@param {object} objectStart the first object to tween to
		@param {object} objectEnd the last object to tween to
		@param {number} delay how long to wait before executing tween
		@param {object} callback name of function to call after tween is done
		@param {object} callbackContext the context the callback will be called with
	*/
	In: function(game, object, objectStart, objectEnd, delay, callback, callbackContext, timeIn, timeOut) {
		var delay = delay || 0;
		var timeIn = timeIn || 300;
		var timeOut = timeOut || 150;
		var t = game.add.tween(object);
		t.to(objectStart, timeIn, Phaser.Easing.Quadratic.Out).to(objectEnd, timeOut, Phaser.Easing.Quadratic.In);
		t.delay(delay);
		if(callback) {
			t.onComplete.add(callback, callbackContext);
		}
		t.start();
		return t;
	},
	
	/**
		Tween out objects using set tween functions
		@method Utils.Tween.Out
		@param {object} game game object for context
		@param {object} object object or object property to tween
		@param {object} objectStart the first object to tween to
		@param {object} objectEnd the last object to tween to
		@param {number} delay how long to wait before executing tween
		@param {object} callback name of function to call after tween is done
		@param {object} callbackContext the context the callback will be called with
	*/
	Out: function(game, object, objectStart, objectEnd, delay, callback, callbackContext, timeIn, timeOut){
		var delay = delay || 0;
		var timeIn = timeIn || 150;
		var timeOut = timeOut || 300;
		var t = game.add.tween(object);
		t.to(objectStart, timeIn, Phaser.Easing.Quadratic.Out).to(objectEnd, timeOut, Phaser.Easing.Quadratic.In);
		t.delay(delay);
		if(callback) {
			t.onComplete.add(callback, callbackContext);
		}
		t.start();
		return t;
	},
	
	/**
		Tween objects in and out using set tween functions
		@method Utils.Tween.InOut
		@param {object} game game object for context
		@param {object} object object or object property to tween
		@param {object} objectStart the first object to tween to
		@param {object} objectEnd the last object to tween to
		@param {number} delay how long to wait before executing tween
		@param {object} callback name of function to call after tween is done
		@param {object} callbackContext the context the callback will be called with
	*/
	InOut: function(game, object, objectStart, objectEnd, delay, callback, callbackContext){
		var delay = delay || 0;
		var t = game.add.tween(object);
		t.to(objectStart, 150, Phaser.Easing.Quadratic.Out).to(objectEnd, 150, Phaser.Easing.Quadratic.In);
		t.delay(delay);
		if(callback) {
			t.onComplete.add(callback, callbackContext);
		}
		t.start();
	}
};